@@ -29,26 +29,27 @@ https://pypi.python.org/pypi/svglib/
 
 @author: oberron
 """
+#standard modules
+import calendar, time, datetime
+import datetime
+import functools
+import locale
+from math import floor
 from os.path import abspath, join, pardir
+import sys, encodings, encodings.aliases
 
+#pip modules
 from reportlab.lib import pagesizes
 from reportlab.pdfgen.canvas import Canvas
-import calendar, time, datetime
-from math import floor
-import locale
-import datetime
 from reportlab.pdfbase.cidfonts import UnicodeCIDFont,findCMapFile
 from reportlab.lib.codecharts import KutenRowCodeChart,hBoxText
 from reportlab.pdfbase import pdfmetrics
 from reportlab.pdfbase.pdfmetrics import stringWidth
 from reportlab.pdfbase.ttfonts import TTFont
 
-import sys, encodings, encodings.aliases
-import functools
-
-## from PIP
 from lunardate import LunarDate
 from svglib.svglib import svg2rlg
+
 from pyICSParser import pyiCalendar
 """
 from pyICSParser import pyiCalendar
@@ -559,7 +560,8 @@ class pdfCalendar():
         FontsSmallTable = {"Font_Size_DOM":Font_Size_DOM_ST,"Font_Size_DOW":Font_Size_DOW_ST,"FontType":"Times-Roman"}
         MonthPicture = MonthStart
         MonthTable = MonthStart
-        MonthPictureIndex = self.conf["pictures"][(MonthPicture.month-1) % (len(self.conf["pictures"]))]
+        if self.ShowPix:
+            MonthPictureIndex = self.conf["pictures"][(MonthPicture.month-1) % (len(self.conf["pictures"]))]
 
         
         height_mo = 100
@@ -607,6 +609,7 @@ class pdfCalendar():
         image_full_path = abspath(join(self.defaultpath,MonthPictureIndex["path"]))
         image_height = localheight-height_mo-2*self.margins["top"]
         if self.template.find("no-pix")<0:
+            #FIXME: seems like broken logic
             if self.ShowPix:
                 #self.pcal.drawImage(Pictures["path"],x0,y0+height_mo+self.margins["bottom"],self.width-2*self.margins["right"],localheight-height_mo-2*self.margins["top"])
                 self.pcal.drawImage(image_full_path,x0,y0+height_mo+self.margins["bottom"],self.width-2*self.margins["right"],localheight-height_mo-2*self.margins["top"],preserveAspectRatio=self.preserveAspectRatio)
@@ -616,7 +619,7 @@ class pdfCalendar():
                 self.pcal.drawString(0, 0, MonthPictureIndex["description"])
         #            self.pcal.drawCentredString(0, 0,  MonthPictureIndex["description"])
                 self.pcal.restoreState()
-                self._log("pictures",Pictures,0)
+                #self._log("pictures",Pictures,0)
             else:
                 #def drawCentredString(self, x, y, text,mode=None):
                 #Draws a string centred on the x coordinate. 
@@ -688,7 +691,7 @@ class pdfCalendar():
                 #MonthPicturePath = self.defaultpath+self.conf["pictures"][(NumberPages+1-MonthStart.month) %len(self.conf["pictures"])]["path"]
                 MonthPicturePath = abspath(join(self.defaultpath,self.conf["pictures"][(NumberPages+1-MonthStart.month) %len(self.conf["pictures"])]["path"]))
                 self.pcal.drawImage(MonthPicturePath,-self.width/2+self.margins["right"],self.margins["top"]+height_mo-self.height/4,self.width-2*self.margins["right"],localheight-height_mo-2*self.margins["top"],preserveAspectRatio=self.preserveAspectRatio)
-                self._log("pictures",Pictures,0)
+                #self._log("pictures",Pictures,0)
             else:
                 self.pcal.drawCentredString(0, 0,  "Picture displayed here")
             self.pcal.restoreState()
@@ -857,7 +860,7 @@ class pdfCalendar():
 
         self.pcal.showPage()
         while (calStart <= dtend):
-            self.addMonth(calStart,NumberMonths = MonthEnd-MonthStart+1, CalType = self.conf["calscale"],Pictures = self.conf["pictures"][index % (len(self.conf["pictures"]))])
+            self.addMonth(calStart,NumberMonths = MonthEnd-MonthStart+1, CalType = self.conf["calscale"]) #,Pictures = self.conf["pictures"][index % (len(self.conf["pictures"]))])
             calStart = self.NextMonth(calStart)
             self._log("printing month", [calStart.month], level = -1)
             index +=1
